
package interfazgrafica10;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JProgressBar;
import javax.swing.JSlider;

public class Componentes {
      
      private JFrame jFrame;
      private JSlider jSlider;  
      private JProgressBar jProgresBar;
      private JLabel jLabel;
    
    public JFrame getjFrame() {
        return jFrame;
    }

    public void setjFrame(JFrame jFrame) {
        this.jFrame = jFrame;
    }
    
    public JSlider getjSlider() {
        return jSlider;
    }

    public void setjSlider(JSlider jSlider) {
        this.jSlider = jSlider;
    }

    public JProgressBar getjProgresBar() {
        return jProgresBar;
    }

    public void setjProgresBar(JProgressBar jProgresBar) {
        this.jProgresBar = jProgresBar;
    }

    public JLabel getjLabel() {
        return jLabel;
    }

    public void setjLabel(JLabel jLabel) {
        this.jLabel = jLabel;
    }
}
